#
# spec file for package ghc-wai-routing
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name wai-routing
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.12.3
Release:        7.14
Summary:        Declarative routing for WAI
License:        MPL-2.0
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-bytestring-conversion-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-predicates-devel
BuildRequires:  ghc-wai-route-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
Enables the declaration of "routes" which handle requests to a specific URL.

The set of possible handlers can be restricted by "predicates", which operate
on WAI requests and have to be true or else the handler will not be called.

Example:

>import Data.ByteString (ByteString) >import Data.Text (Text) >import
Network.Wai >import Network.Wai.Predicate >import Network.Wai.Routing >import
Network.Wai.Handler.Warp > >main :: IO () >main = run 8080 (route (prepare
start)) > >start :: Monad m => Routes a m () >start = do > get "/user/:name"
(continue fetchUser) $ > capture "name" > > get "/user/find" (continue
findUser) $ > query "byName" ||| query "byId" > > delete "/user/:name" rmUser $
> capture "name" .&. opt (cookie "foo") > >fetchUser :: Monad m => Text -> m
Response >fetchUser name = ... > >findUser :: Monad m => Either ByteString
Word64 -> m Response >findUser (Left name) = ... >findUser (Right ident) = ...
> >rmUser :: Monad m => Text ::: Maybe Int -> Continue m -> m ResponseReceived
>rmUser (name ::: foo) k = k $ ...

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md examples

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.12.3 revision 0 with cabal2obs.
